@@ -1,7 +1,5 @@
-# tests/test-topicsModel.R
 library(testthat)
-library(topics)  # Replace with your package name
-#library(text)
+library(topics)
 library(tibble)
 
 test_that("topicsGrams with default parameters", {
